@@ -1,7 +1,7 @@
 package PowerManagement::Any;
 
 our $DATE = '2019-05-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,10 @@ sub _prevent_or_unprevent_sleep_or_check {
             return $res;
         }
         $is_masked = $res->[2];
-        return [200, "OK", $is_masked] if $which eq 'check';
+        return [200, "OK", $is_masked, {
+            'cmdline.exit_code' => !$is_masked,
+            'cmdline.result' => '',
+        }] if $which eq 'check';
         return [304, "sleep.target already masked"]
             if $which eq 'prevent' && $is_masked;
         return [304, "sleep.target already unmasked"]
@@ -169,7 +172,7 @@ PowerManagement::Any - Common interface to some power management tasks
 
 =head1 VERSION
 
-This document describes version 0.002 of PowerManagement::Any (from Perl distribution PowerManagement-Any), released on 2019-05-22.
+This document describes version 0.003 of PowerManagement::Any (from Perl distribution PowerManagement-Any), released on 2019-05-22.
 
 =head1 NOTES
 
